Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/external/mit/xorg/lib/libxcb/files updates for generated files.



details:   https://anonhg.NetBSD.org/src/rev/03d2e401aa2f
branches:  trunk
changeset: 368452:03d2e401aa2f
user:      mrg <mrg%NetBSD.org@localhost>
date:      Tue Jul 12 02:44:09 2022 +0000

description:
updates for generated files.

diffstat:

 external/mit/xorg/lib/libxcb/files/config.h      |   122 +-
 external/mit/xorg/lib/libxcb/files/damage.h      |     3 +
 external/mit/xorg/lib/libxcb/files/dri3.c        |    60 +
 external/mit/xorg/lib/libxcb/files/dri3.h        |    68 +-
 external/mit/xorg/lib/libxcb/files/glx.c         |    26 +-
 external/mit/xorg/lib/libxcb/files/randr.h       |    19 +-
 external/mit/xorg/lib/libxcb/files/record.h      |     2 +
 external/mit/xorg/lib/libxcb/files/render.h      |    15 +
 external/mit/xorg/lib/libxcb/files/screensaver.c |     6 +-
 external/mit/xorg/lib/libxcb/files/screensaver.h |     7 +-
 external/mit/xorg/lib/libxcb/files/shm.h         |     5 +-
 external/mit/xorg/lib/libxcb/files/xf86vidmode.c |  2560 ----------------------
 external/mit/xorg/lib/libxcb/files/xf86vidmode.h |  2013 -----------------
 external/mit/xorg/lib/libxcb/files/xfixes.c      |   108 +
 external/mit/xorg/lib/libxcb/files/xfixes.h      |   125 +-
 external/mit/xorg/lib/libxcb/files/xinput.c      |    72 +-
 external/mit/xorg/lib/libxcb/files/xinput.h      |   169 +-
 external/mit/xorg/lib/libxcb/files/xproto.h      |    12 +-
 external/mit/xorg/lib/libxcb/files/xv.h          |     9 +
 19 files changed, 737 insertions(+), 4664 deletions(-)

diffs (truncated from 5958 to 300 lines):

diff -r 8ad993fe3cc5 -r 03d2e401aa2f external/mit/xorg/lib/libxcb/files/damage.h
--- a/external/mit/xorg/lib/libxcb/files/damage.h       Tue Jul 12 02:43:46 2022 +0000
+++ b/external/mit/xorg/lib/libxcb/files/damage.h       Tue Jul 12 02:44:09 2022 +0000
@@ -53,6 +53,9 @@
     uint8_t  response_type;
     uint8_t  error_code;
     uint16_t sequence;
+    uint32_t bad_value;
+    uint16_t minor_opcode;
+    uint8_t  major_opcode;
 } xcb_damage_bad_damage_error_t;
 
 /**
diff -r 8ad993fe3cc5 -r 03d2e401aa2f external/mit/xorg/lib/libxcb/files/dri3.c
--- a/external/mit/xorg/lib/libxcb/files/dri3.c Tue Jul 12 02:43:46 2022 +0000
+++ b/external/mit/xorg/lib/libxcb/files/dri3.c Tue Jul 12 02:44:09 2022 +0000
@@ -917,3 +917,63 @@
     return xcb_get_reply_fds(c, reply, sizeof(xcb_dri3_buffers_from_pixmap_reply_t) + 4 * reply->length);
 }
 
+xcb_void_cookie_t
+xcb_dri3_set_drm_device_in_use_checked (xcb_connection_t *c,
+                                        xcb_window_t      window,
+                                        uint32_t          drmMajor,
+                                        uint32_t          drmMinor)
+{
+    static const xcb_protocol_request_t xcb_req = {
+        .count = 2,
+        .ext = &xcb_dri3_id,
+        .opcode = XCB_DRI3_SET_DRM_DEVICE_IN_USE,
+        .isvoid = 1
+    };
+
+    struct iovec xcb_parts[4];
+    xcb_void_cookie_t xcb_ret;
+    xcb_dri3_set_drm_device_in_use_request_t xcb_out;
+
+    xcb_out.window = window;
+    xcb_out.drmMajor = drmMajor;
+    xcb_out.drmMinor = drmMinor;
+
+    xcb_parts[2].iov_base = (char *) &xcb_out;
+    xcb_parts[2].iov_len = sizeof(xcb_out);
+    xcb_parts[3].iov_base = 0;
+    xcb_parts[3].iov_len = -xcb_parts[2].iov_len & 3;
+
+    xcb_ret.sequence = xcb_send_request(c, XCB_REQUEST_CHECKED, xcb_parts + 2, &xcb_req);
+    return xcb_ret;
+}
+
+xcb_void_cookie_t
+xcb_dri3_set_drm_device_in_use (xcb_connection_t *c,
+                                xcb_window_t      window,
+                                uint32_t          drmMajor,
+                                uint32_t          drmMinor)
+{
+    static const xcb_protocol_request_t xcb_req = {
+        .count = 2,
+        .ext = &xcb_dri3_id,
+        .opcode = XCB_DRI3_SET_DRM_DEVICE_IN_USE,
+        .isvoid = 1
+    };
+
+    struct iovec xcb_parts[4];
+    xcb_void_cookie_t xcb_ret;
+    xcb_dri3_set_drm_device_in_use_request_t xcb_out;
+
+    xcb_out.window = window;
+    xcb_out.drmMajor = drmMajor;
+    xcb_out.drmMinor = drmMinor;
+
+    xcb_parts[2].iov_base = (char *) &xcb_out;
+    xcb_parts[2].iov_len = sizeof(xcb_out);
+    xcb_parts[3].iov_base = 0;
+    xcb_parts[3].iov_len = -xcb_parts[2].iov_len & 3;
+
+    xcb_ret.sequence = xcb_send_request(c, 0, xcb_parts + 2, &xcb_req);
+    return xcb_ret;
+}
+
diff -r 8ad993fe3cc5 -r 03d2e401aa2f external/mit/xorg/lib/libxcb/files/dri3.h
--- a/external/mit/xorg/lib/libxcb/files/dri3.h Tue Jul 12 02:43:46 2022 +0000
+++ b/external/mit/xorg/lib/libxcb/files/dri3.h Tue Jul 12 02:44:09 2022 +0000
@@ -20,7 +20,7 @@
 #endif
 
 #define XCB_DRI3_MAJOR_VERSION 1
-#define XCB_DRI3_MINOR_VERSION 2
+#define XCB_DRI3_MINOR_VERSION 3
 
 extern xcb_extension_t xcb_dri3_id;
 
@@ -297,6 +297,21 @@
     uint8_t  pad1[6];
 } xcb_dri3_buffers_from_pixmap_reply_t;
 
+/** Opcode for xcb_dri3_set_drm_device_in_use. */
+#define XCB_DRI3_SET_DRM_DEVICE_IN_USE 9
+
+/**
+ * @brief xcb_dri3_set_drm_device_in_use_request_t
+ **/
+typedef struct xcb_dri3_set_drm_device_in_use_request_t {
+    uint8_t      major_opcode;
+    uint8_t      minor_opcode;
+    uint16_t     length;
+    xcb_window_t window;
+    uint32_t     drmMajor;



Home | Main Index | Thread Index | Old Index
diff -r 8ad993fe3cc5 -r 03d2e401aa2f external/mit/xorg/lib/libxcb/files/config.h
--- a/external/mit/xorg/lib/libxcb/files/config.h       Tue Jul 12 02:43:46 2022 +0000
+++ b/external/mit/xorg/lib/libxcb/files/config.h       Tue Jul 12 02:44:09 2022 +0000
@@ -28,8 +28,8 @@
 /* Define to 1 if you have the `ws2_32' library (-lws2_32). */
 /* #undef HAVE_LIBWS2_32 */
 
 /* Define to 1 if you have the <memory.h> header file. */
 #define HAVE_MEMORY_H 1
 
 /* Define if your platform supports sendmsg */
 #define HAVE_SENDMSG 1
@@ -40,6 +40,9 @@
 /* Define to 1 if you have the <stdint.h> header file. */
 #define HAVE_STDINT_H 1
 
+/* Define to 1 if you have the <stdio.h> header file. */
+#define HAVE_STDIO_H 1
+
 /* Define to 1 if you have the <stdlib.h> header file. */
 #define HAVE_STDLIB_H 1
 
@@ -61,6 +64,9 @@
 /* Define to 1 if you have the <unistd.h> header file. */
 #define HAVE_UNISTD_H 1
 
+/* Define to 1 if you have the <wchar.h> header file. */
+#define HAVE_WCHAR_H 1
+
 /* Define if not provided by <limits.h> */
 /* #undef IOV_MAX */
 
@@ -71,13 +77,13 @@
 #define PACKAGE "libxcb"
 
 /* Define to the address where bug reports for this package should be sent. */
-#define PACKAGE_BUGREPORT "https://bugs.freedesktop.org/enter_bug.cgi?product=xcb";
+#define PACKAGE_BUGREPORT "https://gitlab.freedesktop.org/xorg/lib/libxcb/issues";
 
 /* Define to the full name of this package. */
 #define PACKAGE_NAME "libxcb"
 
 /* Define to the full name and version of this package. */
-#define PACKAGE_STRING "libxcb 1.13"
+#define PACKAGE_STRING "libxcb 1.15"
 
 /* Define to the one symbol short name of this package. */
 #define PACKAGE_TARNAME "libxcb"
@@ -86,18 +92,20 @@
 #define PACKAGE_URL ""
 
 /* Define to the version of this package. */
-#define PACKAGE_VERSION "1.13"
+#define PACKAGE_VERSION "1.15"
 
 /* Major version of this package */
 #define PACKAGE_VERSION_MAJOR 1
 
 /* Minor version of this package */
-#define PACKAGE_VERSION_MINOR 13
+#define PACKAGE_VERSION_MINOR 15
 
 /* Patch version of this package */
 #define PACKAGE_VERSION_PATCHLEVEL 0
 
-/* Define to 1 if you have the ANSI C header files. */
+/* Define to 1 if all of the C90 standard headers exist (not just the ones
+   required in a freestanding environment). This macro is provided for
+   backward compatibility; new code need not use it. */
 #define STDC_HEADERS 1
 
 /* poll() function is available */
@@ -107,39 +115,95 @@
 #ifndef _ALL_SOURCE
 # define _ALL_SOURCE 1
 #endif
-/* Enable GNU extensions on systems that have them.  */
-#ifndef _GNU_SOURCE
-# define _GNU_SOURCE 1
-#endif
-/* Enable threading extensions on Solaris.  */
-#ifndef _POSIX_PTHREAD_SEMANTICS
-# define _POSIX_PTHREAD_SEMANTICS 1
-#endif
-/* Enable extensions on HP NonStop.  */
-#ifndef _TANDEM_SOURCE
-# define _TANDEM_SOURCE 1
+/* Enable general extensions on macOS.  */
+#ifndef _DARWIN_C_SOURCE
+# define _DARWIN_C_SOURCE 1
 #endif
 /* Enable general extensions on Solaris.  */
 #ifndef __EXTENSIONS__
 # define __EXTENSIONS__ 1
 #endif
+/* Enable GNU extensions on systems that have them.  */
+#ifndef _GNU_SOURCE
+# define _GNU_SOURCE 1
+#endif
+/* Enable X/Open compliant socket functions that do not require linking
+   with -lxnet on HP-UX 11.11.  */
+#ifndef _HPUX_ALT_XOPEN_SOCKET_API
+# define _HPUX_ALT_XOPEN_SOCKET_API 1
+#endif
+/* Identify the host operating system as Minix.
+   This macro does not affect the system headers' behavior.
+   A future release of Autoconf may stop defining this macro.  */
+#ifndef _MINIX
+/* # undef _MINIX */
+#endif
+/* Enable general extensions on NetBSD.
+   Enable NetBSD compatibility extensions on Minix.  */
+#ifndef _NETBSD_SOURCE
+# define _NETBSD_SOURCE 1
+#endif
+/* Enable OpenBSD compatibility extensions on NetBSD.
+   Oddly enough, this does nothing on OpenBSD.  */
+#ifndef _OPENBSD_SOURCE
+# define _OPENBSD_SOURCE 1
+#endif
+/* Define to 1 if needed for POSIX-compatible behavior.  */
+#ifndef _POSIX_SOURCE
+/* # undef _POSIX_SOURCE */
+#endif
+/* Define to 2 if needed for POSIX-compatible behavior.  */
+#ifndef _POSIX_1_SOURCE
+/* # undef _POSIX_1_SOURCE */
+#endif
+/* Enable POSIX-compatible threading on Solaris.  */
+#ifndef _POSIX_PTHREAD_SEMANTICS
+# define _POSIX_PTHREAD_SEMANTICS 1
+#endif
+/* Enable extensions specified by ISO/IEC TS 18661-5:2014.  */
+#ifndef __STDC_WANT_IEC_60559_ATTRIBS_EXT__
+# define __STDC_WANT_IEC_60559_ATTRIBS_EXT__ 1
+#endif
+/* Enable extensions specified by ISO/IEC TS 18661-1:2014.  */
+#ifndef __STDC_WANT_IEC_60559_BFP_EXT__
+# define __STDC_WANT_IEC_60559_BFP_EXT__ 1
+#endif
+/* Enable extensions specified by ISO/IEC TS 18661-2:2015.  */
+#ifndef __STDC_WANT_IEC_60559_DFP_EXT__
+# define __STDC_WANT_IEC_60559_DFP_EXT__ 1
+#endif
+/* Enable extensions specified by ISO/IEC TS 18661-4:2015.  */
+#ifndef __STDC_WANT_IEC_60559_FUNCS_EXT__
+# define __STDC_WANT_IEC_60559_FUNCS_EXT__ 1
+#endif
+/* Enable extensions specified by ISO/IEC TS 18661-3:2015.  */
+#ifndef __STDC_WANT_IEC_60559_TYPES_EXT__
+# define __STDC_WANT_IEC_60559_TYPES_EXT__ 1
+#endif
+/* Enable extensions specified by ISO/IEC TR 24731-2:2010.  */
+#ifndef __STDC_WANT_LIB_EXT2__
+# define __STDC_WANT_LIB_EXT2__ 1
+#endif
+/* Enable extensions specified by ISO/IEC 24747:2009.  */
+#ifndef __STDC_WANT_MATH_SPEC_FUNCS__
+# define __STDC_WANT_MATH_SPEC_FUNCS__ 1
+#endif
+/* Enable extensions on HP NonStop.  */
+#ifndef _TANDEM_SOURCE
+# define _TANDEM_SOURCE 1
+#endif
+/* Enable X/Open extensions.  Define to 500 only if necessary
+   to make mbstate_t available.  */
+#ifndef _XOPEN_SOURCE
+/* # undef _XOPEN_SOURCE */
+#endif
 
 
 /* Version number of package */
-#define VERSION "1.13"
+#define VERSION "1.15"
 
 /* XCB buffer queue size */
 #define XCB_QUEUE_BUFFER_SIZE 16384
 
-/* Define to 1 if on MINIX. */
-/* #undef _MINIX */
-
-/* Define to 2 if the system does not provide POSIX.1 features except with
-   this defined. */
-/* #undef _POSIX_1_SOURCE */
-
-/* Define to 1 if you need to in order for `stat' and other things to work. */
-/* #undef _POSIX_SOURCE */
-
 /* Defined if needed to expose struct msghdr.msg_control */
 /* #undef _XOPEN_SOURCE */
@@ -28,8 +28,8 @@
 /* #undef HAVE_LIBWS2_32 */
 
-/* Define to 1 if you have the <memory.h> header file. */
-#define HAVE_MEMORY_H 1
+/* Define to 1 if you have the <minix/config.h> header file. */
+/* #undef HAVE_MINIX_CONFIG_H */
 
 /* Define if your platform supports sendmsg */